# lib/Software/Licemse/OrLaterPack.pm #

#   This file is part of Software-License-OrLaterPack.
#
#   Software-License-OrLaterPack is free software: you can redistribute it
#   and/or modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   Software-License-OrLaterPack is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
#   Public License for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with Software-License-OrLaterPack.  If not, see
#   <http://www.gnu.org/licenses/>.

package Software::License::OrLaterPack;

# ABSTRACT: GPLv3+ and AGPLv3+ for Software::License

use 5.008;
use strict;
use warnings;

# VERSION

use Software::License::AGPL_3::or_later;
use Software::License::GPL_3::or_later;

1;

=pod

=encoding UTF-8

=head1 SYNOPSIS

In C<dist.ini>:

    name             = Foo-Bar
    version          = 0.001
    author           = John Doe <john.doe@example.com>
    license          = GPL_3::or_later ; <<== Note 'or_later' <<==
        ; or another license, see the list of provided licenses below
    copyright_holder = John Doe
    copyright_year   = 2015
    …

Direct usage:

    use Software::License::GPL_3::or_later; # <<== Note 'or_later' <<==
        # or another license, see the list provided licenses below
    my $license =
        Software::License::GPL_3::or_later->new( {
            holder => 'John Doe', …
        } );
    print( $license->notice );
    …

=head1 PURPOSE

L<Dist::Zilla>, a popular tool for building packages for CPAN, allows you to specify software
license for your distribution in C<dist.ini> file, e. g.:

    license = NAME

where I<NAME> is a short license name, like C<Perl_5> or C<BSD>. When building your package,
C<dzil> will add "COPYRIGHT AND LICENSE" section to the documentation, add appropriate C<LICENSE>
file to your distribution, etc. C<Dist::Zilla> uses licenses provided by C<Software::License>
module. The latter is shipped with a set of popular software licenses, including GNU General Public
License (GNU GPL) versions 1, 2, and 3, denoted by names C<GPL_1>, C<GPL_2>, and C<GPL_3>
respectively.

L<Free Software Foundation|https://fsf.org/>, a developer of GNU GPL, recommends not to stick to a
specific version of the GNU license, but allow "upgrading" it by using clause "license version I<N>
or (at your option) any later version". See the
L<rationale|https://www.gnu.org/licenses/gpl-faq.html#VersionThreeOrLater>.

However, L<Software::License> distribution does not provide (ready to use out of the box) a way to
express such conditions. This module partially fulfills the lack.

=head1 LIST OF PROVIDED LICENSES

=for :list
= L<Software::License::AGPL_3::or_later>
= L<Software::License::GPL_3::or_later>

Let me know if you need other licenses, e. g. GPLv2+ or LGPLv3+.

=head1 SOURCE CODE

Perl modules included into the distribution tarball are not actual sources: they are preprocessed 
by L<Dist::Zilla> and its plugins. Actual source code can be downloaded from 
Software-License-OrLaterPack Mercurial repository:

    $ hg clone http://hg.code.sf.net/p/orlaterpack/code/

=head1 CAVEATS

L<CPAN::Meta::Spec> hardcodes the list of "valid" licenses. In version 2.150001 of the module there
are no "upgradable" GNU licenses, so in CPAN the GPLv3+ will look as ordinal GPLv3 (C<gpl_3>), and
so on.

=head1 SEE ALSO

=for :list
= L<Dist::Zilla>
= L<Software::License>
= L<Software::License::AGPL_3>
= L<Software::License::AGPL_3::or_later>
= L<Software::License::GPL_3>
= L<Software::License::GPL_3::or_later>
= L<Why should programs say “Version 3 of the GPL or any later version”?|https://www.gnu.org/licenses/gpl-faq.html#VersionThreeOrLater>

=cut

# end of file #
